@@ -16,6 +16,10 @@ class GitignoreFeature(Feature):
     def name(self) -> str:
         return "gitignore"
 
+    @property
+    def dependencies(self) -> Iterable[str]:
+        return ["core"]
+
     @property
     def schema(self) -> ClassVar[GitignoreSchema]:
         return GitignoreSchema
